@@ -66,6 +66,22 @@ typedef struct _presence_data_t
 
 HD_DEFINE_PLUGIN_MODULE(PresenceNotifierStatusPlugin, presence_notifier_status_plugin, HD_TYPE_STATUS_MENU_ITEM);
 
+static void
+_print_presence_data(presence_data_t* presence_data)
+{
+  g_warning("presence data\n");
+  g_warning("message %s\n", presence_data->status_message);
+  g_warning("type %d\n", presence_data->presence_type);
+}
+
+static void
+_print_contact_presence(OssoABookPresence* presence)
+{
+  g_warning("contact presence\n");
+  g_warning("message %s\n", osso_abook_presence_get_presence_status_message(presence));
+  g_warning("type %d\n", osso_abook_presence_get_presence_type(presence));
+}
+
 static void presence_data_free(presence_data_t* data)
 {
   g_free(data->status_message);
@@ -128,7 +144,6 @@ _notify_on_change(PresenceNotifierStatusPlugin* plugin,
      connection_status != TP_CONNECTION_STATUS_CONNECTED)
     return;
 
-  
   gchar* contact_status = g_strdup(osso_abook_presence_get_presence_status(presence));
   gchar* contact_status_message = g_strdup(osso_abook_presence_get_presence_status_message(presence));
   gboolean message_changed = g_strcmp0(presence_data->status_message, contact_status_message) != 0;
@@ -136,7 +151,6 @@ _notify_on_change(PresenceNotifierStatusPlugin* plugin,
     presence_data->presence_type != contact_status_type;
   if(message_changed || status_changed)
   {
-    
     if(presence_data->status_message != NULL)
       g_free(presence_data->status_message);
     if(presence_data->status != NULL)
@@ -144,6 +158,8 @@ _notify_on_change(PresenceNotifierStatusPlugin* plugin,
 
     presence_data->status_message = contact_status_message;
     presence_data->status = contact_status;
+    TpConnectionPresenceType prior_status_type = presence_data->presence_type;
+    
     presence_data->presence_type = contact_status_type;
     
     if(!plugin->priv->disabled &&
@@ -155,7 +171,8 @@ _notify_on_change(PresenceNotifierStatusPlugin* plugin,
 	 (!plugin->priv->notify_online_status_only && 
 	  (status_changed || (plugin->priv->notify_message_change && message_changed))
 	   )
-	 )
+	 ) &&
+       prior_status_type != TP_CONNECTION_PRESENCE_TYPE_UNKNOWN
       )
     {
       _show_presence_message(plugin, presence);
@@ -174,9 +191,12 @@ _roster_contact_presence_status_message(OssoABookPresence* presence,
 					gpointer user)
 {
   PresenceNotifierStatusPlugin* plugin = PRESENCE_NOTIFIER_STATUS_PLUGIN(user);
-
+  /* g_warning("notify status message\n"); */
+  /* g_warning("contact %s\n", osso_abook_contact_get_name(OSSO_ABOOK_CONTACT(presence))); */
+  /* _print_contact_presence(presence); */
   presence_data_t* contact_presence = g_hash_table_lookup(plugin->priv->contacts, 
 							  osso_abook_contact_get_persistent_uid(OSSO_ABOOK_CONTACT(presence)));
+  _print_presence_data(contact_presence);
   _notify_on_change(plugin, presence, contact_presence);
 }
 
@@ -186,9 +206,14 @@ _roster_contact_presence_type(OssoABookPresence* presence,
 			      gpointer user)
 {
   PresenceNotifierStatusPlugin* plugin = PRESENCE_NOTIFIER_STATUS_PLUGIN(user);
+  /* g_warning("notify presence type\n"); */
+  /* g_warning("contact %s\n", osso_abook_contact_get_name(OSSO_ABOOK_CONTACT(presence))); */
+  /* _print_contact_presence(presence); */
 
   presence_data_t* contact_presence = g_hash_table_lookup(plugin->priv->contacts, 
 							  osso_abook_contact_get_persistent_uid(OSSO_ABOOK_CONTACT(presence)));
+  _print_presence_data(contact_presence);
+
   _notify_on_change(plugin, presence, contact_presence);
 }
 static void
@@ -197,57 +222,13 @@ _roster_contact_presence_status(OssoABookPresence* presence,
 				gpointer user)
 {
   PresenceNotifierStatusPlugin* plugin = PRESENCE_NOTIFIER_STATUS_PLUGIN(user);
+  /* g_warning("notify status\n"); */
+  /* g_warning("contact %s\n", osso_abook_contact_get_name(OSSO_ABOOK_CONTACT(presence))); */
+  /* _print_contact_presence(presence); */
   presence_data_t* contact_presence = g_hash_table_lookup(plugin->priv->contacts, 
 							    osso_abook_contact_get_persistent_uid(OSSO_ABOOK_CONTACT(presence)));
+  _print_presence_data(contact_presence);
   _notify_on_change(plugin, presence, contact_presence);
-  /*
-  if(!plugin->priv->disabled &&
-     osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_UNSET &&
-     osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_UNKNOWN &&
-     osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_ERROR &&
-     mc_account_get_connection_status(osso_abook_contact_get_account(OSSO_ABOOK_CONTACT(presence))) == TP_CONNECTION_STATUS_CONNECTED)
-  {
-
-
-
-    if(contact_presence)
-    {
-	
-      if((osso_abook_presence_get_presence_status(presence) == NULL &&
-	  g_strcmp0(contact_presence->status_message, osso_abook_presence_get_presence_status_message(presence)) != 0) ||
-	 (osso_abook_presence_get_presence_status_message(presence) == NULL &&
-	  g_strcmp0(contact_presence->status, osso_abook_presence_get_presence_status(presence)) != 0))
-      {
-	g_free(contact_presence->status_message);
-	g_free(contact_presence->status);
-	contact_presence->status_message = g_strdup(osso_abook_presence_get_presence_status_message(presence));
-	contact_presence->status = g_strdup(osso_abook_presence_get_presence_status(presence));
-	contact_presence->presence_type = osso_abook_presence_get_presence_type(presence);
-	_show_presence_message(plugin,
-			       presence);
-      }
-      else
-      {
-	g_warning("message %s\n", contact_presence->status_message);
-      }
-    }
-    else
-    {
-      g_warning("not found %s\n", osso_abook_contact_get_persistent_uid(OSSO_ABOOK_CONTACT(presence)));
-    }
-  }
-  */
-  /*
-  if(!plugin->priv->disabled &&
-    osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_UNSET &&
-     osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_UNKNOWN &&
-     osso_abook_presence_get_presence_type(presence) != TP_CONNECTION_PRESENCE_TYPE_ERROR &&
-     mc_account_get_connection_status(osso_abook_contact_get_account(OSSO_ABOOK_CONTACT(presence))) == TP_CONNECTION_STATUS_CONNECTED)
-  {
-    _show_presence_message(plugin,
-			   presence);
-  }
-  */
 }
 
 static void
@@ -266,11 +247,6 @@ presence_data_for_contact(OssoABookContact* contact)
   const gchar* status_message = osso_abook_presence_get_presence_status_message(presence);
   const gchar* status = osso_abook_presence_get_presence_status(presence);
   TpConnectionPresenceType presence_type =  osso_abook_presence_get_presence_type(presence);
-  g_warning("create presence\n");
-  g_warning("name %s\n", osso_abook_contact_get_persistent_uid(contact));
-  g_warning("status_message %s\n", status_message);
-  g_warning("status %s\n", status);
-  g_warning("type %d\n", presence_type);
   presence_data->status_message = g_strdup(status_message);
   presence_data->status = g_strdup(status);
   presence_data->presence_type = presence_type;
@@ -287,6 +263,10 @@ _list_roster_contacts(PresenceNotifierStatusPlugin* plugin)
     OssoABookContact* roster_contact = (OssoABookContact*) roster->data;
     gchar* name = g_strdup(osso_abook_contact_get_persistent_uid(roster_contact));
     presence_data_t* presence_data = presence_data_for_contact(roster_contact);
+    /* g_warning("list roster\n"); */
+    /* g_warning("contact %s\n", osso_abook_contact_get_name(roster_contact)); */
+    /* _print_contact_presence(OSSO_ABOOK_PRESENCE(roster_contact)); */
+    /* _print_presence_data(presence_data); */
 
     g_hash_table_insert(plugin->priv->contacts,
 			name,
